@@ -283,10 +283,11 @@ class CohortFileStandard:
 
     def edit_cohort(self, new_cohort_name, new_description, cohort_path):
         returned_path_name = None
-        if new_cohort_name:
-            returned_path_name = self._edit_cohort_name(cohort_path, new_cohort_name)
+        # calling functions to edit description and then cohort name
         if new_description:
             self._edit_cohort_description(cohort_path, new_description)
+        if new_cohort_name:
+            returned_path_name = self._edit_cohort_name(cohort_path, new_cohort_name)
         return returned_path_name
 
     def _edit_cohort_name(self, cohort_path, new_cohort_name: str):
@@ -314,8 +315,7 @@ class CohortFileStandard:
         """
         if not (new_description and isinstance(new_description, str)):
             return
-        existing_path = cohort_path
-        meta_path = helpers.make_path(existing_path, "cohort.meta")
+        meta_path = helpers.make_path(cohort_path, "cohort.meta")
         json_data = None
         with open(meta_path, "r+b") as openfile:
             byte = openfile.read()
@@ -329,7 +329,7 @@ class CohortFileStandard:
             openfile.truncate()
         logging.basicConfig(level=logging.INFO)
         logging.info("Cohort Description Updated!")
-        self._cohort_path = json_data
+        self._cohort_details = json_data
 
     def is_valid(self, cohort_path: str) -> bool:
         """
